@@ -1,4 +1,4 @@
-/*	$OpenBSD: extern.h,v 1.197 2023/12/27 07:15:55 tb Exp $ */
+/*	$OpenBSD: extern.h,v 1.203 2024/02/03 14:30:47 job Exp $ */
 /*
  * Copyright (c) 2019 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -219,7 +219,6 @@ struct mft {
 	size_t		 filesz; /* number of filenames */
 	unsigned int	 repoid;
 	int		 talid;
-	int		 stale; /* if a stale manifest */
 };
 
 /*
@@ -366,7 +365,7 @@ struct aspa {
 	uint32_t		*providers; /* the providers */
 	size_t			 providersz; /* number of providers */
 	time_t			 signtime; /* CMS signing-time attribute */
-	time_t		 	 notbefore; /* EE cert's Not Before */
+	time_t			 notbefore; /* EE cert's Not Before */
 	time_t			 notafter; /* notAfter of the ASPA EE cert */
 	time_t			 expires; /* when the signature path expires */
 };
@@ -435,7 +434,7 @@ struct crl {
 	char		*aki;
 	char		*number;
 	X509_CRL	*x509_crl;
-	time_t		 lastupdate;	/* do not use before */
+	time_t		 thisupdate;	/* do not use before */
 	time_t		 nextupdate;	/* do not use after */
 };
 /*
@@ -527,7 +526,6 @@ enum stype {
 	STYPE_OK,
 	STYPE_FAIL,
 	STYPE_INVALID,
-	STYPE_STALE,
 	STYPE_BGPSEC,
 	STYPE_TOTAL,
 	STYPE_UNIQUE,
@@ -548,7 +546,6 @@ struct repotalstats {
 	uint32_t	 certs_fail; /* invalid certificate */
 	uint32_t	 mfts; /* total number of manifests */
 	uint32_t	 mfts_fail; /* failing syntactic parse */
-	uint32_t	 mfts_stale; /* stale manifests */
 	uint32_t	 roas; /* route origin authorizations */
 	uint32_t	 roas_fail; /* failing syntactic parse */
 	uint32_t	 roas_invalid; /* invalid resources */
@@ -629,7 +626,8 @@ void		 mft_free(struct mft *);
 struct mft	*mft_parse(X509 **, const char *, int, const unsigned char *,
 		    size_t);
 struct mft	*mft_read(struct ibuf *);
-int		 mft_compare(const struct mft *, const struct mft *);
+int		 mft_compare_issued(const struct mft *, const struct mft *);
+int		 mft_compare_seqnum(const struct mft *, const struct mft *);
 
 void		 roa_buffer(struct ibuf *, const struct roa *);
 void		 roa_free(struct roa *);
@@ -860,6 +858,7 @@ int		 x509_valid_subject(const char *, const X509 *);
 time_t		 x509_find_expires(time_t, struct auth *, struct crl_tree *);
 
 /* printers */
+char		*nid2str(int);
 char		*time2str(time_t);
 void		 x509_print(const X509 *);
 void		 tal_print(const struct tal *);
