@@ -1,4 +1,4 @@
-/*	$OpenBSD: mft.c,v 1.100 2023/12/11 15:50:23 job Exp $ */
+/*	$OpenBSD: mft.c,v 1.106 2024/02/05 19:23:58 job Exp $ */
 /*
  * Copyright (c) 2022 Theo Buehler <tb@openbsd.org>
  * Copyright (c) 2019 Kristaps Dzonsons <kristaps@bsd.lv>
@@ -89,58 +89,6 @@ IMPLEMENT_ASN1_FUNCTIONS(Manifest);
 
 #define GENTIME_LENGTH 15
 
-/*
- * Convert an ASN1_GENERALIZEDTIME to a struct tm.
- * Returns 1 on success, 0 on failure.
- */
-static int
-generalizedtime_to_tm(const ASN1_GENERALIZEDTIME *gtime, struct tm *tm)
-{
-	/*
-	 * ASN1_GENERALIZEDTIME is another name for ASN1_STRING. Check type and
-	 * length, so we don't accidentally accept a UTCTime. Punt on checking
-	 * Zulu time for OpenSSL: we don't want to mess about with silly flags.
-	 */
-	if (ASN1_STRING_type(gtime) != V_ASN1_GENERALIZEDTIME)
-		return 0;
-	if (ASN1_STRING_length(gtime) != GENTIME_LENGTH)
-		return 0;
-
-	memset(tm, 0, sizeof(*tm));
-	return ASN1_TIME_to_tm(gtime, tm);
-}
-
-/*
- * Validate and verify the time validity of the mft.
- * Returns 1 if all is good and for any other case 0.
- */
-static int
-mft_parse_time(const ASN1_GENERALIZEDTIME *from,
-    const ASN1_GENERALIZEDTIME *until, struct parse *p)
-{
-	struct tm tm_from, tm_until;
-
-	if (!generalizedtime_to_tm(from, &tm_from)) {
-		warnx("%s: embedded from time format invalid", p->fn);
-		return 0;
-	}
-	if (!generalizedtime_to_tm(until, &tm_until)) {
-		warnx("%s: embedded until time format invalid", p->fn);
-		return 0;
-	}
-
-	if ((p->res->thisupdate = timegm(&tm_from)) == -1 ||
-	    (p->res->nextupdate = timegm(&tm_until)) == -1)
-		errx(1, "%s: timegm failed", p->fn);
-
-	if (p->res->thisupdate > p->res->nextupdate) {
-		warnx("%s: bad update interval", p->fn);
-		return 0;
-	}
-
-	return 1;
-}
-
 /*
  * Determine rtype corresponding to file extension. Returns RTYPE_INVALID
  * on error or unkown extension.
@@ -284,15 +232,22 @@ mft_parse_filehash(struct parse *p, const FileAndHash *fh)
 static int
 mft_parse_econtent(const unsigned char *d, size_t dsz, struct parse *p)
 {
+	const unsigned char	*oder;
 	Manifest		*mft;
 	FileAndHash		*fh;
 	int			 i, rc = 0;
 
+	oder = d;
 	if ((mft = d2i_Manifest(NULL, &d, dsz)) == NULL) {
 		warnx("%s: RFC 6486 section 4: failed to parse Manifest",
 		    p->fn);
 		goto out;
 	}
+	if (d != oder + dsz) {
+		warnx("%s: %td bytes trailing garbage in eContent", p->fn,
+		    oder + dsz - d);
+		goto out;
+	}
 
 	if (!valid_econtent_version(p->fn, mft->version, 0))
 		goto out;
@@ -302,17 +257,31 @@ mft_parse_econtent(const unsigned char *d, size_t dsz, struct parse *p)
 		goto out;
 
 	/*
-	 * Timestamps: this and next update time.
-	 * Validate that the current date falls into this interval.
-	 * This is required by section 4.4, (3).
-	 * If we're after the given date, then the MFT is stale.
-	 * This is made super complicated because it uses OpenSSL's
-	 * ASN1_GENERALIZEDTIME instead of ASN1_TIME, which we could
-	 * compare against the current time trivially.
+	 * OpenSSL's DER decoder implementation will accept a GeneralizedTime
+	 * which doesn't conform to RFC 5280. So, double check.
 	 */
-
-	if (!mft_parse_time(mft->thisUpdate, mft->nextUpdate, p))
+	if (ASN1_STRING_length(mft->thisUpdate) != GENTIME_LENGTH) {
+		warnx("%s: embedded from time format invalid", p->fn);
 		goto out;
+	}
+	if (ASN1_STRING_length(mft->nextUpdate) != GENTIME_LENGTH) {
+		warnx("%s: embedded until time format invalid", p->fn);
+		goto out;
+	}
+
+	if (!x509_get_time(mft->thisUpdate, &p->res->thisupdate)) {
+		warn("%s: parsing manifest thisUpdate failed", p->fn);
+		goto out;
+	}
+	if (!x509_get_time(mft->nextUpdate, &p->res->nextupdate)) {
+		warn("%s: parsing manifest nextUpdate failed", p->fn);
+		goto out;
+	}
+
+	if (p->res->thisupdate > p->res->nextupdate) {
+		warnx("%s: bad update interval", p->fn);
+		goto out;
+	}
 
 	if (OBJ_obj2nid(mft->fileHashAlg) != NID_sha256) {
 		warnx("%s: RFC 6486 section 4.2.1: fileHashAlg: "
@@ -352,10 +321,7 @@ mft_parse_econtent(const unsigned char *d, size_t dsz, struct parse *p)
 
 /*
  * Parse the objects that have been published in the manifest.
- * This conforms to RFC 6486.
- * Note that if the MFT is stale, all referenced objects are stripped
- * from the parsed content.
- * The MFT content is otherwise returned.
+ * Return mft if it conforms to RFC 6486, otherwise NULL.
  */
 struct mft *
 mft_parse(X509 **x509, const char *fn, int talid, const unsigned char *der,
@@ -486,7 +452,6 @@ mft_buffer(struct ibuf *b, const struct mft *p)
 {
 	size_t		 i;
 
-	io_simple_buffer(b, &p->stale, sizeof(p->stale));
 	io_simple_buffer(b, &p->repoid, sizeof(p->repoid));
 	io_simple_buffer(b, &p->talid, sizeof(p->talid));
 	io_str_buffer(b, p->path);
@@ -519,7 +484,6 @@ mft_read(struct ibuf *b)
 	if ((p = calloc(1, sizeof(struct mft))) == NULL)
 		err(1, NULL);
 
-	io_read_buf(b, &p->stale, sizeof(p->stale));
 	io_read_buf(b, &p->repoid, sizeof(p->repoid));
 	io_read_buf(b, &p->talid, sizeof(p->talid));
 	io_read_str(b, &p->path);
@@ -545,20 +509,26 @@ mft_read(struct ibuf *b)
 }
 
 /*
- * Compare the manifestNumber of two MFT files.
- * Returns 1 if first MFT should be used, 0 if both are equal, and -1 if the
- * second MFT should be used.
+ * Compare the thisupdate time of two mft files.
  */
 int
-mft_compare(const struct mft *a, const struct mft *b)
+mft_compare_issued(const struct mft *a, const struct mft *b)
+{
+	if (a->thisupdate > b->thisupdate)
+		return 1;
+	if (a->thisupdate < b->thisupdate)
+		return -1;
+	return 0;
+}
+
+/*
+ * Compare the manifestNumber of two mft files.
+ */
+int
+mft_compare_seqnum(const struct mft *a, const struct mft *b)
 {
 	int r;
 
-	if (b == NULL)
-		return 1;
-	if (a == NULL)
-		return -1;
-
 	r = strlen(a->seqnum) - strlen(b->seqnum);
 	if (r > 0)	/* seqnum in a is longer -> higher */
 		return 1;
