@@ -1,4 +1,4 @@
-/*	$OpenBSD: print.c,v 1.44 2023/11/16 11:18:47 tb Exp $ */
+/*	$OpenBSD: print.c,v 1.46 2024/02/01 15:11:38 tb Exp $ */
 /*
  * Copyright (c) 2021 Claudio Jeker <claudio@openbsd.org>
  * Copyright (c) 2019 Kristaps Dzonsons <kristaps@bsd.lv>
@@ -49,6 +49,22 @@ pretty_key_id(const char *hex)
 	return buf;
 }
 
+char *
+nid2str(int nid)
+{
+	static char buf[128];
+	const char *name;
+
+	if ((name = OBJ_nid2ln(nid)) == NULL)
+		name = OBJ_nid2sn(nid);
+	if (name == NULL)
+		name = "unknown";
+
+	snprintf(buf, sizeof(buf), "nid %d (%s)", nid, name);
+
+	return buf;
+}
+
 char *
 time2str(time_t t)
 {
@@ -352,12 +368,12 @@ crl_print(const struct crl *p)
 	free(issuer);
 
 	if (outformats & FORMAT_JSON) {
-		json_do_int("valid_since", p->lastupdate);
+		json_do_int("valid_since", p->thisupdate);
 		json_do_int("valid_until", p->nextupdate);
 		json_do_array("revoked_certs");
 	} else {
-		printf("CRL last update:          %s\n",
-		    time2str(p->lastupdate));
+		printf("CRL this update:          %s\n",
+		    time2str(p->thisupdate));
 		printf("CRL next update:          %s\n",
 		    time2str(p->nextupdate));
 		printf("Revoked Certificates:\n");
